summaryrefslogtreecommitdiffstats
path: root/konq-plugins/rsync/rsyncconfigdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'konq-plugins/rsync/rsyncconfigdialog.h')
-rw-r--r--konq-plugins/rsync/rsyncconfigdialog.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/konq-plugins/rsync/rsyncconfigdialog.h b/konq-plugins/rsync/rsyncconfigdialog.h
index 38f8687..8e02d54 100644
--- a/konq-plugins/rsync/rsyncconfigdialog.h
+++ b/konq-plugins/rsync/rsyncconfigdialog.h
@@ -19,10 +19,10 @@
#ifndef __RSYNC_CONFIG_DIALOG_H
#define __RSYNC_CONFIG_DIALOG_H
-#include <qmap.h>
-#include <qstringlist.h>
-#include <qlineedit.h>
-#include <qradiobutton.h>
+#include <tqmap.h>
+#include <tqstringlist.h>
+#include <tqlineedit.h>
+#include <tqradiobutton.h>
#include <kurl.h>
#include <kprocess.h>
@@ -39,26 +39,26 @@ class RsyncConfigDialog : public KDialogBase
Q_OBJECT
public:
- RsyncConfigDialog(QWidget* parent = 0, const char* name = 0,
- const QString& caption = QString::null,
- const QString& text = QString::null,
- const QString& localfolder = QString::null,
- const QString& remotefolder = QString::null,
+ RsyncConfigDialog(TQWidget* parent = 0, const char* name = 0,
+ const TQString& caption = TQString::null,
+ const TQString& text = TQString::null,
+ const TQString& localfolder = TQString::null,
+ const TQString& remotefolder = TQString::null,
int syncmode = 1, bool modal = false);
/**
* Returns the QLineEdit used in this dialog.
* To set the number of lines or other text box related
* settings, access the KTextEdit object directly via this method.
*/
- QLineEdit* lineEdit();
+ TQLineEdit* lineEdit();
/**
* Returns the QLineEdit used in this dialog.
* To set the number of lines or other text box related
* settings, access the KTextEdit object directly via this method.
*/
- const QLineEdit* lineEdit() const;
+ const TQLineEdit* lineEdit() const;
/**
* Returns index of selected synchronization mode
@@ -75,14 +75,14 @@ class RsyncConfigDialog : public KDialogBase
bool mAllowCancel;
bool mAllowTextEdit;
bool mShown;
- QString mCancelText;
- QLabel* mLabel;
+ TQString mCancelText;
+ TQLabel* mLabel;
KProgress* mProgressBar;
KTextEdit* mTextBox;
- QTimer* mShowTimer;
- QLineEdit* m_rsync_txt;
- QRadioButton *rsync_rb1;
- QRadioButton *rsync_rb2;
- QRadioButton *rsync_rb3;
+ TQTimer* mShowTimer;
+ TQLineEdit* m_rsync_txt;
+ TQRadioButton *rsync_rb1;
+ TQRadioButton *rsync_rb2;
+ TQRadioButton *rsync_rb3;
};
#endif
@@ -39,26 +39,26 @@ class RsyncConfigDialog : public KDialogBase
int syncmode = 1, bool modal = false);
/**
- * Returns the QLineEdit used in this dialog.
+ * Returns the TQLineEdit used in this dialog.
* To set the number of lines or other text box related
* settings, access the KTextEdit object directly via this method.
@@ -39,26 +39,26 @@ class RsyncConfigDialog : public KDialogBase
/**
- * Returns the QLineEdit used in this dialog.
+ * Returns the TQLineEdit used in this dialog.
* To set the number of lines or other text box related
* settings, access the KTextEdit object directly via this method.